use v5.36;
use utf8;
use AWS::Lambda::PSGI;
use Paws;

# DynamoDB に接続するためのクライアントを作成
my $db = Paws->service(
    'DynamoDB',
    region => $ENV{AWS_DEFAULT_REGION}
);

my $app = sub {
    # カウンタをインクリメント
    my $ret = $db->UpdateItem(
        # DynamoDB のテーブル名
        TableName => $ENV{TABLE_NAME},

        # プライマリーキーの指定
        Key => { id => { S => "data" } },

        # インクリメント命令を実行
        # :incr の部分はプレースホルダー
        UpdateExpression => 'ADD cnt :incr',

        # プレースホルダー :incr に 1 を設定
        ExpressionAttributeValues => {
            ':incr' => { N => '1' }
        },

        # 戻り値に更新後の値を返すよう設定
        ReturnValues => 'UPDATED_NEW',
    );

    # 結果を返す
    my $cnt = $ret->Attributes->Map->{cnt}->N;
    return [
        200,
        ['Content-Type' => 'text/plain'],
        ["$cnt\n"]
    ];
};

my $func = AWS::Lambda::PSGI->wrap($app);

sub handle ($payload, $context) {
    return $func->($payload);
}

1;
